==> MediaWikiLanguageExtensionBundle-2012.12.tar.bz2: extensions/cldr/CldrNames/CldrNamesKi.php <==
<?php

$languageNames = array(
'ak' => 'Kiakan',
'am' => 'Kiamhari',
'ar' => 'Kĩarabu',
'be' => 'Kibelarusi',
'bg' => 'Kibulgaria',
'bn' => 'Kibangla',
'cs' => 'Kichecki',
'de' => 'Kĩnjeremani',
'el' => 'Kigiriki',
'en' => 'Gĩthungũ',
'es' => 'Kihispania',
'fa' => 'Kiajemi',
'fr' => 'Kĩbaranja',
'ha' => 'Kihausa',
'hi' => 'Kĩhĩndĩ',
'hu' => 'Kihungari',
'id' => 'Kiindonesia',
'ig' => 'Kiigbo',
'it' => 'Kĩtaliano',
'ja' => 'Kĩnjabani',
'jv' => 'Kijava',
'ki' => 'Gikuyu',
'km' => 'Kikambodia',
'ko' => 'Kikorea',
'ms' => 'Kimalesia',
'my' => 'Kiburma',
'ne' => 'Kinepali',
'nl' => 'Kiholanzi',
'pa' => 'Kipunjabi',
'pl' => 'Kipolandi',
'pt' => 'Kireno',
'ro' => 'Kiromania',
'ru' => 'Kĩracia',
'rw' => 'Kinyarwanda',
'so' => 'Kĩcumarĩ',
'sv' => 'Kiswidi',
'ta' => 'Kitamil',
'th' => 'Kitailandi',
'tr' => 'Kituruki',
'uk' => 'Kiukrania',
'ur' => 'Kiurdu',
'vi' => 'Kivietinamu',
'yo' => 'Kiyoruba',
'zh' => 'Kĩcaina',
'zu' => 'Kizulu',
);

$currencyNames = array(
'AED' => 'Dirham ya Falme za Kiarabu',
'AOA' => 'Kwanza ya Angola',
'AUD' => 'Dola ya Australia',
'BHD' => 'Dinari ya Bahareni',
'BIF' => 'Faranga ya Burundi',
'BWP' => 'Pula ya Botswana',
'CAD' => 'Ndora ya Kananda',
'CDF' => 'Faranga ya Kongo',
'CHF' => 'Faranga ya Uswisi',
'CNY' => 'Yuan Renminbi ya China',
'CVE' => 'Eskudo ya Kepuvede',
'DJF' => 'Faranga ya Jibuti',
'DZD' => 'Dinari ya Aljeria',
'EGP' => 'Pauni ya Misri',
'ERN' => 'Nakfa ya Eritrea',
'ETB' => 'Bir ya Uhabeshi',
'EUR' => 'Yuro',
'GBP' => 'Mbauini cia Ngeretha',
'GHC' => 'Sedi ya Ghana',
'GMD' => 'Dalasi ya Gambia',
'GNS' => 'Faranga ya Gine',
'INR' => 'Rubia rwa India',
'JPY' => 'Sarafu ya Kijapani',
'KES' => 'Ciringi ya Kenya',
'KMF' => 'Faranga ya Komoro',
'LRD' => 'Dola ya Liberia',
'LSL' => 'Loti ya Lesoto',
'LYD' => 'Dinari ya Libya',
'MAD' => 'Dirham ya Moroko',
'MGA' => 'Ariary ya Bukini',
'MRO' => 'Ugwiya ya Moritania',
'MUR' => 'Rupia ya Morisi',
'MWK' => 'Kwacha ya Malawi',
'MZM' => 'Metikali ya Msumbiji',
'NAD' => 'Dola ya Namibia',
'NGN' => 'Naira ya Nijeria',
'RWF' => 'Faranga ya Rwanda',
'SAR' => 'Riyal ya Saudia',
'SCR' => 'Rupia ya Shelisheli',
'SDG' => 'Pauni ya Sudani',
'SHP' => 'Pauni ya Santahelena',
'SLL' => 'Leoni',
'SOS' => 'ciringi cia cumarĩ',
'STD' => 'Dobra ya Sao Tome na Principe',
'SZL' => 'Lilangeni',
'TND' => 'Dinari ya Tunisia',
'TZS' => 'ciringi cia Tanizania',
'UGX' => 'ciringi ciaŨganda',
'USD' => 'Ndora cia Amerika',
'XAF' => 'Faranga CFA BEAC',
'XOF' => 'Faranga CFA BCEAO',
'ZAR' => 'Randi ya Afrika Kusini',
'ZMK' => 'Kwacha ya Zambia',
'ZWD' => 'Dola ya Zimbabwe',
);

$countryNames = array(
'AD' => 'Andora',
'AE' => 'Falme za Kiarabu',
'AF' => 'Afuganistani',
'AG' => 'Antigua na Barbuda',
'AI' => 'Anguilla',
'AL' => 'Albania',
'AM' => 'Armenia',
'AN' => 'Antili za Uholanzi',
'AO' => 'Angola',
'AR' => 'Ajentina',
'AS' => 'Samoa ya Marekani',
'AT' => 'Austria',
'AU' => 'Australia',
'AW' => 'Aruba',
'AZ' => 'Azabajani',
'BA' => 'Bosnia na Hezegovina',
'BB' => 'Babadosi',
'BD' => 'Bangladeshi',
'BE' => 'Ubelgiji',
'BF' => 'Bukinafaso',
'BG' => 'Bulgaria',
'BH' => 'Bahareni',
'BI' => 'Mburundi',
'BJ' => 'Benini',
'BM' => 'Bermuda',
'BN' => 'Brunei',
'BO' => 'Bolivia',
'BR' => 'Brazili',
'BS' => 'Bahama',
'BT' => 'Butani',
'BW' => 'Botswana',
'BY' => 'Belarusi',
'BZ' => 'Belize',
'CA' => 'Kanada',
'CD' => 'Jamhuri ya Kidemokrasia ya Kongo',
'CF' => 'Jamhuri ya Afrika ya Kati',
'CG' => 'Kongo',
'CH' => 'Uswisi',
'CI' => 'Kodivaa',
'CK' => 'Visiwa vya Cook',
'CL' => 'Chile',
'CM' => 'Kameruni',
'CN' => 'Caina',
'CO' => 'Kolombia',
'CR' => 'Kostarika',
'CU' => 'Kiumba',
'CV' => 'Kepuvede',
'CY' => 'Kuprosi',
'CZ' => 'Jamhuri ya Cheki',
'DE' => 'Njeremani',
'DJ' => 'Jibuti',
'DK' => 'Denmaki',
'DM' => 'Dominika',
'DO' => 'Jamhuri ya Dominika',
'DZ' => 'Aljeria',
'EC' => 'Ekwado',
'EE' => 'Estonia',
'EG' => 'Misri',
'ER' => 'Eritrea',
'ES' => 'Hispania',
'ET' => 'Uhabeshi',
'FI' => 'Ufini',
'FJ' => 'Fiji',
'FK' => 'Visiwa vya Falkland',
'FM' => 'Mikronesia',
'FR' => 'Ubaranja',
'GA' => 'Gaboni',
'GB' => 'Ngeretha',
'GD' => 'Grenada',
'GE' => 'Jojia',
'GF' => 'Gwiyana ya Ufaransa',
'GH' => 'Ngana',
'GI' => 'Jibralta',
'GL' => 'Grinlandi',
'GM' => 'Gambia',
'GN' => 'Gine',
'GP' => 'Gwadelupe',
'GQ' => 'Ginekweta',
'GR' => 'Ugiriki',
'GT' => 'Gwatemala',
'GU' => 'Gwam',
'GW' => 'Ginebisau',
'GY' => 'Guyana',
'HN' => 'Hondurasi',
'HR' => 'Korasia',
'HT' => 'Haiti',
'HU' => 'Hungaria',
'ID' => 'Indonesia',
'IE' => 'Ayalandi',
'IL' => 'Israeli',
'IN' => 'India',
'IO' => 'Eneo la Uingereza katika Bahari Hindi',
'IQ' => 'Iraki',
'IR' => 'Uajemi',
'IS' => 'Aislandi',
'IT' => 'Italia',
'JM' => 'Jamaika',
'JO' => 'Njorondani',
'JP' => 'Njabani',
'KE' => 'Kenya',
'KG' => 'Kirigizistani',
'KH' => 'Kambodia',
'KI' => 'Kiribati',
'KM' => 'Komoro',
'KN' => 'Santakitzi na Nevis',
'KP' => 'Korea Kaskazini',
'KR' => 'Korea Kusini',
'KW' => 'Kuwaiti',
'KY' => 'Visiwa vya Kayman',
'KZ' => 'Kazakistani',
'LA' => 'Laosi',
'LB' => 'Lebanoni',
'LC' => 'Santalusia',
'LI' => 'Lishenteni',
'LK' => 'Sirilanka',
'LR' => 'Liberia',
'LS' => 'Lesoto',
'LT' => 'Litwania',
'LU' => 'Lasembagi',
'LV' => 'Lativia',
'LY' => 'Libya',
'MA' => 'Moroko',
'MC' => 'Monako',
'MD' => 'Moldova',
'MG' => 'Bukini',
'MH' => 'Visiwa vya Marshal',
'MK' => 'Masedonia',
'ML' => 'Mali',
'MM' => 'Myama',
'MN' => 'Mongolia',
'MP' => 'Visiwa vya Mariana vya Kaskazini',
'MQ' => 'Martiniki',
'MR' => 'Moritania',
'MS' => 'Montserrati',
'MT' => 'Malta',
'MU' => 'Morisi',
'MV' => 'Modivu',
'MW' => 'Malawi',
'MX' => 'Meksiko',
'MY' => 'Malesia',
'MZ' => 'Msumbiji',
'NA' => 'Namimbia',
'NC' => 'Nyukaledonia',
'NE' => 'Nijeri',
'NF' => 'Kisiwa cha Norfok',
'NG' => 'Nainjeria',
'NI' => 'Nikaragwa',
'NL' => 'Uholanzi',
'NO' => 'Norwe',
'NP' => 'Nepali',
'NR' => 'Nauru',
'NU' => 'Niue',
'NZ' => 'Nyuzilandi',
'OM' => 'Omani',
'PA' => 'Panama',
'PE' => 'Peru',
'PF' => 'Polinesia ya Ufaransa',
'PG' => 'Papua',
'PH' => 'Filipino',
'PK' => 'Pakistani',
'PL' => 'Polandi',
'PM' => 'Santapieri na Mikeloni',
'PN' => 'Pitkairni',
'PR' => 'Pwetoriko',
'PS' => 'Ukingo wa Magharibi na Ukanda wa Gaza wa Palestina',
'PT' => 'Ureno',
'PW' => 'Palau',
'PY' => 'Paragwai',
'QA' => 'Katari',
'RE' => 'Riyunioni',
'RO' => 'Romania',
'RU' => 'Urusi',
'RW' => 'Rwanda',
'SA' => 'Saudi',
'SB' => 'Visiwa vya Solomon',
'SC' => 'Shelisheli',
'SD' => 'Sudani',
'SE' => 'Uswidi',
'SG' => 'Singapoo',
'SH' => 'Santahelena',
'SI' => 'Slovenia',
'SK' => 'Slovakia',
'SL' => 'Siera Leoni',
'SM' => 'Samarino',
'SN' => 'Senegali',
'SO' => 'Somaria',
'SR' => 'Surinamu',
'ST' => 'Sao Tome na Principe',
'SV' => 'Elsavado',
'SY' => 'Siria',
'SZ' => 'Uswazi',
'TC' => 'Visiwa vya Turki na Kaiko',
'TD' => 'Chadi',
'TG' => 'Togo',
'TH' => 'Tailandi',
'TJ' => 'Tajikistani',
'TK' => 'Tokelau',
'TL' => 'Timori ya Mashariki',
'TM' => 'Turukimenistani',
'TN' => 'Tunisia',
'TO' => 'Tonga',
'TR' => 'Uturuki',
'TT' => 'Trinidad na Tobago',
'TV' => 'Tuvalu',
'TW' => 'Taiwani',
'TZ' => 'Tanzania',
'UA' => 'Ukraini',
'UG' => 'Uganda',
'US' => 'Amerika',
'UY' => 'Urugwai',
'UZ' => 'Uzibekistani',
'VA' => 'Vatikani',
'VC' => 'Santavisenti na Grenadini',
'VE' => 'Venezuela',
'VG' => 'Visiwa vya Virgin vya Uingereza',
'VI' => 'Visiwa vya Virgin vya Marekani',
'VN' => 'Vietinamu',
'VU' => 'Vanuatu',
'WF' => 'Walis na Futuna',
'WS' => 'Samoa',
'YE' => 'Yemeni',
'YT' => 'Mayotte',
'ZA' => 'Afrika Kusini',
'ZM' => 'Zambia',
'ZW' => 'Zimbabwe',
);

==> MediaWikiLanguageExtensionBundle-2013.05.tar.bz2: extensions/cldr/CldrNames/CldrNamesKi.php <==
<?php

$languageNames = array(
'ak' => 'Kiakan',
'am' => 'Kiamhari',
'ar' => 'Kĩarabu',
'be' => 'Kibelarusi',
'bg' => 'Kibulgaria',
'bn' => 'Kibangla',
'cs' => 'Kichecki',
'de' => 'Kĩnjeremani',
'el' => 'Kigiriki',
'en' => 'Gĩthungũ',
'es' => 'Kihispania',
'fa' => 'Kiajemi',
'fr' => 'Kĩbaranja',
'ha' => 'Kihausa',
'hi' => 'Kĩhĩndĩ',
'hu' => 'Kihungari',
'id' => 'Kiindonesia',
'ig' => 'Kiigbo',
'it' => 'Kĩtaliano',
'ja' => 'Kĩnjabani',
'jv' => 'Kijava',
'ki' => 'Gikuyu',
'km' => 'Kikambodia',
'ko' => 'Kikorea',
'ms' => 'Kimalesia',
'my' => 'Kiburma',
'ne' => 'Kinepali',
'nl' => 'Kiholanzi',
'pa' => 'Kipunjabi',
'pl' => 'Kipolandi',
'pt' => 'Kireno',
'ro' => 'Kiromania',
'ru' => 'Kĩracia',
'rw' => 'Kinyarwanda',
'so' => 'Kĩcumarĩ',
'sv' => 'Kiswidi',
'ta' => 'Kitamil',
'th' => 'Kitailandi',
'tr' => 'Kituruki',
'uk' => 'Kiukrania',
'ur' => 'Kiurdu',
'vi' => 'Kivietinamu',
'yo' => 'Kiyoruba',
'zh' => 'Kĩcaina',
'zu' => 'Kizulu',
);

$currencyNames = array(
'AED' => 'Dirham ya Falme za Kiarabu',
'AOA' => 'Kwanza ya Angola',
'AUD' => 'Dola ya Australia',
'BHD' => 'Dinari ya Bahareni',
'BIF' => 'Faranga ya Burundi',
'BWP' => 'Pula ya Botswana',
'CAD' => 'Ndora ya Kananda',
'CDF' => 'Faranga ya Kongo',
'CHF' => 'Faranga ya Uswisi',
'CNY' => 'Yuan Renminbi ya China',
'CVE' => 'Eskudo ya Kepuvede',
'DJF' => 'Faranga ya Jibuti',
'DZD' => 'Dinari ya Aljeria',
'EGP' => 'Pauni ya Misri',
'ERN' => 'Nakfa ya Eritrea',
'ETB' => 'Bir ya Uhabeshi',
'EUR' => 'Yuro',
'GBP' => 'Mbauini cia Ngeretha',
'GHC' => 'Sedi ya Ghana',
'GMD' => 'Dalasi ya Gambia',
'GNS' => 'Faranga ya Gine',
'INR' => 'Rubia rwa India',
'JPY' => 'Sarafu ya Kijapani',
'KES' => 'Ciringi ya Kenya',
'KMF' => 'Faranga ya Komoro',
'LRD' => 'Dola ya Liberia',
'LSL' => 'Loti ya Lesoto',
'LYD' => 'Dinari ya Libya',
'MAD' => 'Dirham ya Moroko',
'MGA' => 'Ariary ya Bukini',
'MRO' => 'Ugwiya ya Moritania',
'MUR' => 'Rupia ya Morisi',
'MWK' => 'Kwacha ya Malawi',
'MZM' => 'Metikali ya Msumbiji',
'NAD' => 'Dola ya Namibia',
'NGN' => 'Naira ya Nijeria',
'RWF' => 'Faranga ya Rwanda',
'SAR' => 'Riyal ya Saudia',
'SCR' => 'Rupia ya Shelisheli',
'SDG' => 'Pauni ya Sudani',
'SHP' => 'Pauni ya Santahelena',
'SLL' => 'Leoni',
'SOS' => 'ciringi cia cumarĩ',
'STD' => 'Dobra ya Sao Tome na Principe',
'SZL' => 'Lilangeni',
'TND' => 'Dinari ya Tunisia',
'TZS' => 'ciringi cia Tanizania',
'UGX' => 'ciringi cia Ũganda',
'USD' => 'Ndora cia Amerika',
'XAF' => 'Faranga CFA BEAC',
'XOF' => 'Faranga CFA BCEAO',
'ZAR' => 'Randi ya Afrika Kusini',
'ZMK' => 'Kwacha ya Zambia (1968-2012)',
'ZMW' => 'Kwacha ya Zambia',
'ZWD' => 'Dola ya Zimbabwe',
);

$countryNames = array(
'AD' => 'Andora',
'AE' => 'Falme za Kiarabu',
'AF' => 'Afuganistani',
'AG' => 'Antigua na Barbuda',
'AI' => 'Anguilla',
'AL' => 'Albania',
'AM' => 'Armenia',
'AN' => 'Antili za Uholanzi',
'AO' => 'Angola',
'AR' => 'Ajentina',
'AS' => 'Samoa ya Marekani',
'AT' => 'Austria',
'AU' => 'Australia',
'AW' => 'Aruba',
'AZ' => 'Azabajani',
'BA' => 'Bosnia na Hezegovina',
'BB' => 'Babadosi',
'BD' => 'Bangladeshi',
'BE' => 'Ubelgiji',
'BF' => 'Bukinafaso',
'BG' => 'Bulgaria',
'BH' => 'Bahareni',
'BI' => 'Mburundi',
'BJ' => 'Benini',
'BM' => 'Bermuda',
'BN' => 'Brunei',
'BO' => 'Bolivia',
'BR' => 'Brazili',
'BS' => 'Bahama',
'BT' => 'Butani',
'BW' => 'Botswana',
'BY' => 'Belarusi',
'BZ' => 'Belize',
'CA' => 'Kanada',
'CD' => 'Jamhuri ya Kidemokrasia ya Kongo',
'CF' => 'Jamhuri ya Afrika ya Kati',
'CG' => 'Kongo',
'CH' => 'Uswisi',
'CI' => 'Kodivaa',
'CK' => 'Visiwa vya Cook',
'CL' => 'Chile',
'CM' => 'Kameruni',
'CN' => 'Caina',
'CO' => 'Kolombia',
'CR' => 'Kostarika',
'CU' => 'Kiumba',
'CV' => 'Kepuvede',
'CY' => 'Kuprosi',
'CZ' => 'Jamhuri ya Cheki',
'DE' => 'Njeremani',
'DJ' => 'Jibuti',
'DK' => 'Denmaki',
'DM' => 'Dominika',
'DO' => 'Jamhuri ya Dominika',
'DZ' => 'Aljeria',
'EC' => 'Ekwado',
'EE' => 'Estonia',
'EG' => 'Misri',
'ER' => 'Eritrea',
'ES' => 'Hispania',
'ET' => 'Uhabeshi',
'FI' => 'Ufini',
'FJ' => 'Fiji',
'FK' => 'Visiwa vya Falkland',
'FM' => 'Mikronesia',
'FR' => 'Ubaranja',
'GA' => 'Gaboni',
'GB' => 'Ngeretha',
'GD' => 'Grenada',
'GE' => 'Jojia',
'GF' => 'Gwiyana ya Ufaransa',
'GH' => 'Ngana',
'GI' => 'Jibralta',
'GL' => 'Grinlandi',
'GM' => 'Gambia',
'GN' => 'Gine',
'GP' => 'Gwadelupe',
'GQ' => 'Ginekweta',
'GR' => 'Ugiriki',
'GT' => 'Gwatemala',
'GU' => 'Gwam',
'GW' => 'Ginebisau',
'GY' => 'Guyana',
'HN' => 'Hondurasi',
'HR' => 'Korasia',
'HT' => 'Haiti',
'HU' => 'Hungaria',
'ID' => 'Indonesia',
'IE' => 'Ayalandi',
'IL' => 'Israeli',
'IN' => 'India',
'IO' => 'Eneo la Uingereza katika Bahari Hindi',
'IQ' => 'Iraki',
'IR' => 'Uajemi',
'IS' => 'Aislandi',
'IT' => 'Italia',
'JM' => 'Jamaika',
'JO' => 'Njorondani',
'JP' => 'Njabani',
'KE' => 'Kenya',
'KG' => 'Kirigizistani',
'KH' => 'Kambodia',
'KI' => 'Kiribati',
'KM' => 'Komoro',
'KN' => 'Santakitzi na Nevis',
'KP' => 'Korea Kaskazini',
'KR' => 'Korea Kusini',
'KW' => 'Kuwaiti',
'KY' => 'Visiwa vya Kayman',
'KZ' => 'Kazakistani',
'LA' => 'Laosi',
'LB' => 'Lebanoni',
'LC' => 'Santalusia',
'LI' => 'Lishenteni',
'LK' => 'Sirilanka',
'LR' => 'Liberia',
'LS' => 'Lesoto',
'LT' => 'Litwania',
'LU' => 'Lasembagi',
'LV' => 'Lativia',
'LY' => 'Libya',
'MA' => 'Moroko',
'MC' => 'Monako',
'MD' => 'Moldova',
'MG' => 'Bukini',
'MH' => 'Visiwa vya Marshal',
'MK' => 'Masedonia',
'ML' => 'Mali',
'MM' => 'Myama',
'MN' => 'Mongolia',
'MP' => 'Visiwa vya Mariana vya Kaskazini',
'MQ' => 'Martiniki',
'MR' => 'Moritania',
'MS' => 'Montserrati',
'MT' => 'Malta',
'MU' => 'Morisi',
'MV' => 'Modivu',
'MW' => 'Malawi',
'MX' => 'Meksiko',
'MY' => 'Malesia',
'MZ' => 'Msumbiji',
'NA' => 'Namimbia',
'NC' => 'Nyukaledonia',
'NE' => 'Nijeri',
'NF' => 'Kisiwa cha Norfok',
'NG' => 'Nainjeria',
'NI' => 'Nikaragwa',
'NL' => 'Uholanzi',
'NO' => 'Norwe',
'NP' => 'Nepali',
'NR' => 'Nauru',
'NU' => 'Niue',
'NZ' => 'Nyuzilandi',
'OM' => 'Omani',
'PA' => 'Panama',
'PE' => 'Peru',
'PF' => 'Polinesia ya Ufaransa',
'PG' => 'Papua',
'PH' => 'Filipino',
'PK' => 'Pakistani',
'PL' => 'Polandi',
'PM' => 'Santapieri na Mikeloni',
'PN' => 'Pitkairni',
'PR' => 'Pwetoriko',
'PS' => 'Ukingo wa Magharibi na Ukanda wa Gaza wa Palestina',
'PT' => 'Ureno',
'PW' => 'Palau',
'PY' => 'Paragwai',
'QA' => 'Katari',
'RE' => 'Riyunioni',
'RO' => 'Romania',
'RU' => 'Urusi',
'RW' => 'Rwanda',
'SA' => 'Saudi',
'SB' => 'Visiwa vya Solomon',
'SC' => 'Shelisheli',
'SD' => 'Sudani',
'SE' => 'Uswidi',
'SG' => 'Singapoo',
'SH' => 'Santahelena',
'SI' => 'Slovenia',
'SK' => 'Slovakia',
'SL' => 'Siera Leoni',
'SM' => 'Samarino',
'SN' => 'Senegali',
'SO' => 'Somaria',
'SR' => 'Surinamu',
'ST' => 'Sao Tome na Principe',
'SV' => 'Elsavado',
'SY' => 'Siria',
'SZ' => 'Uswazi',
'TC' => 'Visiwa vya Turki na Kaiko',
'TD' => 'Chadi',
'TG' => 'Togo',
'TH' => 'Tailandi',
'TJ' => 'Tajikistani',
'TK' => 'Tokelau',
'TL' => 'Timori ya Mashariki',
'TM' => 'Turukimenistani',
'TN' => 'Tunisia',
'TO' => 'Tonga',
'TR' => 'Uturuki',
'TT' => 'Trinidad na Tobago',
'TV' => 'Tuvalu',
'TW' => 'Taiwani',
'TZ' => 'Tanzania',
'UA' => 'Ukraini',
'UG' => 'Uganda',
'US' => 'Amerika',
'UY' => 'Urugwai',
'UZ' => 'Uzibekistani',
'VA' => 'Vatikani',
'VC' => 'Santavisenti na Grenadini',
'VE' => 'Venezuela',
'VG' => 'Visiwa vya Virgin vya Uingereza',
'VI' => 'Visiwa vya Virgin vya Marekani',
'VN' => 'Vietinamu',
'VU' => 'Vanuatu',
'WF' => 'Walis na Futuna',
'WS' => 'Samoa',
'YE' => 'Yemeni',
'YT' => 'Mayotte',
'ZA' => 'Afrika Kusini',
'ZM' => 'Zambia',
'ZW' => 'Zimbabwe',
);
